@@ -7,13 +7,13 @@ from facebook_api import fields
 from facebook_api.utils import graph
 from facebook_api.decorators import atomic
 from facebook_api.models import FacebookGraphIDModel, FacebookGraphManager
-from parser import FacebookPageFansParser, FacebookParseError
+from .parser import FacebookPageFansParser, FacebookParseError
 import logging
 import re
 
 log = logging.getLogger('facebook_pages')
 
-PAGES_FANS_USER_ID = getattr(settings, 'FACEBOOK_PAGES_FANS_USER_ID')
+PAGES_FANS_USER_ID = getattr(settings, 'FACEBOOK_PAGES_FANS_USER_ID', '')
 
 class FacebookPageGraphManager(FacebookGraphManager):
 
