@@ -1,10 +1,18 @@
 # -*- coding: utf-8 -*-
 from django.test import TestCase
-from models import Page
 from facebook_posts.models import Post, get_or_create_from_small_resource
+from models import Page, PAGES_FANS_USER_ID
+from parser import FacebookPageFansParser
+from factories import PageFactory
+from BeautifulSoup import BeautifulSoup
+from parser import FacebookParser, FacebookParseError
+
 
 PAGE_ID = '19292868552'
 PAGE_RESOURCE_SHORT = {'category': 'Product/service', 'id': PAGE_ID, 'name': 'Facebook Developers'}
+PAGE_URL = 'https://www.facebook.com/pages/METRO-Cash-and-Carry-Russia/129107667156177'
+
+PAGE_FANS_ID = 501842786534856
 
 class FacebookPagesTest(TestCase):
 
@@ -22,8 +30,18 @@ class FacebookPagesTest(TestCase):
         self.assertEqual(page.website, 'http://developers.facebook.com')
         self.assertEqual(page.category, "Product/service")
         self.assertEqual(page.username, 'FacebookDevelopers')
-        self.assertEqual(page.company_overview, 'Facebook Platform enables anyone to build social apps on Facebook, mobile, and the web.')
-        self.assertEqual(page.link, 'http://www.facebook.com/FacebookDevelopers')
+        self.assertEqual(page.link, 'https://www.facebook.com/FacebookDevelopers')
+        self.assertTrue(len(page.company_overview) > 0)
+        self.assertTrue(page.likes_count > 0)
+
+    def test_get_by_url(self):
+
+        page = Page.remote.get_by_url('https://www.facebook.com/pages/METRO-Cash-and-Carry-Russia/129107667156177')
+
+        self.assertEqual(page.graph_id, '129107667156177')
+        self.assertEqual(page.name, 'METRO Cash and Carry Russia')
+        self.assertEqual(page.is_published, True)
+        self.assertEqual(page.website, 'http://www.metro-cc.ru')
 
     def test_fetch_page_from_resource(self):
 
@@ -38,4 +56,19 @@ class FacebookPagesTest(TestCase):
 
         page2 = get_or_create_from_small_resource(PAGE_RESOURCE_SHORT)
         self.assertEqual(page2.website, "http://developers.facebook.com")
-        self.assertEqual(page2.category, PAGE_RESOURCE_SHORT['category'])
\ No newline at end of file
+        self.assertEqual(page2.category, PAGE_RESOURCE_SHORT['category'])
+
+
+class FacebookPageFansTest(TestCase):
+
+    def test_get_parser_response(self):
+
+        parser = FacebookPageFansParser(authorized=True, url='/ajax/browser/list/page_fans/?page_id=%s&start=0&__user=%s&__a=1' % (PAGE_FANS_ID, PAGES_FANS_USER_ID))
+        self.assertTrue(isinstance(parser.content_bs, BeautifulSoup))
+
+    def test_fetch_fans_ids(self):
+
+        page = PageFactory(graph_id=PAGE_FANS_ID)
+
+        ids = page.fetch_fans_ids_parser()
+        self.assertTrue(len(ids) > 450)
